==> nextcloud-24.0.10.tgz: nextcloud/apps/photos/l10n/cs.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Veřejný odkaz",
    "Photos" : "Fotky",
    "Your memories under your control" : "Vaše vzpomínky pod vaší kontrolou",
    "All media" : "Veškerá média",
    "Videos" : "Videa",
    "Albums" : "Alba",
    "Collaborative albums" : "Alba pro spolupráci",
    "People" : "Lidé",
    "Folders" : "Složky",
    "Favorites" : "Oblíbené",
    "On this day" : "V tento den",
    "Shared with you" : "Sdíleno s vámi",
    "Tags" : "Štítky",
    "Locations" : "Umístění",
    "Photos settings" : "Nastavení pro Fotky",
    "Mark selection as favorite" : "Označit vybrané jako oblíbené",
    "Add selection to favorites" : "Přidat vybrané do oblíbených",
    "Remove selection from favorites" : "Odebrat vybrané z oblíbených",
    "Name of the album" : "Název alba",
    "Location of the album" : "Umístění alba",
    "Go back to the previous view." : "Jít zpět na předchozí pohled.",
    "Back" : "Zpět",
    "Go to the add collaborators view." : "Jít na pohled přidání spolupracujících.",
    "Add collaborators" : "Přidat spolupracující",
    "Save." : "Uložit.",
    "Create the album." : "Vytvořit album.",
    "Save" : "Uložit",
    "Create album" : "Vytvořit album",
    "Back to the new album form." : "Zpět na formulář pro nové album.",
    "Add to Album" : "Přidat do alba",
    "Add selection to album {albumName}" : "Přidat výběr do alba {albumName}",
    "Create a new album." : "Vytvořit nové album.",
    "Create new album" : "Vytvořit nové album",
    "New album" : "Nové album",
    "_%n item_::_%n photos and videos_" : ["%n položka","%n fotky a videa","%n fotek a videí","%n fotky a videa"],
    "_Share with %n user_::_Share with %n users_" : ["Nasdílet %n uživateli","Nasdílet %n uživatelům","Nasdílet %n uživatelům","Nasdílet %n uživatelům"],
    "Add people or groups who can edit your album" : "Přidejte uživatele či skupiny, kteří mohou album upravovat",
    "Search for collaborators" : "Vyhledat spolupracující",
    "Search people or groups" : "Hledat uživatele nebo skupiny",
    "Add {collaboratorLabel} to the collaborators list" : "Přidat {collaboratorLabel} na seznam spolupracujících",
    "No collaborators available" : "Nejsou k dispozici žádní spolupracující",
    "Remove {collaboratorLabel} from the collaborators list" : "Odebrat {collaboratorLabel} ze seznamu spolupracujících",
    "Copy the public link" : "Zkopírovat veřejný odkaz",
    "Public link copied!" : "Veřejný odkaz zkopírován!",
    "Copy public link" : "Zkopírovat veřejný odkaz",
    "Delete the public link" : "Zkopírovat veřejný odkaz",
    "Share via public link" : "Nasdílet prostřednictvím veřejného odkazu",
    "Failed to fetch collaborators list." : "Nepodařilo se získat seznam spolupracujících.",
    "Failed to fetch album." : "Album se nepodařilo stáhnout.",
    "Failed to update album." : "Album se nepodařilo aktualizovat.",
    "This collection does not exist" : "Tato sbírka neexistuje",
    "An error occurred" : "Došlo k chybě",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "Select image {imageName}" : "Vybrat obrázek {imageName}",
    "The file is in the favorites" : "Soubor je v oblíbených",
    "Open the full size \"{name}\" image" : "Otevřít obrázek „{name}“ v plné velikosti",
    "There are no photos or videos yet!" : "Zatím zde nejsou žádné fotky či videa!",
    "Add to {destination}" : "Přidat do {destination}",
    "Open the \"{name}\" sub-directory" : "Otevřít podsložku „{name}“",
    "Back to {folder}" : "Zpět do {folder}",
    "Share this folder" : "Sdílet tuto složku",
    "_{years} year ago_::_{years} years ago_" : ["Před {years} rokem","Před {years} roky","Před {years} lety","Před {years} roky"],
    "Enable squared photos view" : "Zapnout čtvercové zobrazení fotek",
    "Default Photos upload and Albums location" : "Výchozí umístění nahrávání fotek a alb",
    "Select the default location for your media" : "Vyberte výchozí umístění pro vaše média",
    "Invalid location selected" : "Vybráno neplatné umístění",
    "View" : "Zobrazit",
    "Photos directory" : "Složka pro fotky",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "Manage collaborators for this album" : "Spravovat spolupracující pro toto album",
    "Open actions menu" : "Otevřít nabídku akcí",
    "Edit album details" : "Upravit podrobnosti o albu",
    "Download all files in album" : "Stáhnout veškeré soubory v albu",
    "Delete album" : "Smazat album",
    "Download selected files" : "Stáhnout si označené soubory",
    "Remove selection from album" : "Odebrat vybrané z alba",
    "This album does not have any photos or videos yet!" : "Toto album zatím neobsahuje žádné fotky či videa!",
    "Add photos to this album" : "Přidat fotky do tohoto alba",
    "Add photos to the album" : "Přidat fotky do alba",
    "Manage collaborators" : "Spravovat spolupracující",
    "Save collaborators for this album." : "Uložit spolupracující pro toto album.",
    "Cover photo for album {albumName}" : "Foto na obálku alba {albumName}",
    "There is no album yet!" : "Zatím zde nejsou žádná alba",
    "This person could not be found" : "Tuto osobu se nepodařilo nalézt",
    "Rename person" : "Přejmenovat osobu",
    "Merge with different person" : "Sloučit s jinou osobou",
    "Download selected photos" : "Stáhnout si označené fotky",
    "Favorite" : "Přidat do oblíbených",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Remove person" : "Odebrat osobu",
    "Name of this person" : "Pojmenovat tuto osobu",
    "Merge person" : "Sloučit osobu",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Přesunout fotku k jiné osobě","Přesunout fotky k jiné osobě","Přesunout fotky k jiné osobě","Přesunout fotky k jiné osobě"],
    "_Remove photo from person_::_Remove photos from person_" : ["Odebrat fotku z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby"],
    "This might take some time depending on the size of your photo library." : "Toto může zabrat nějakou dobu v závislosti na velikosti vaší knihovny fotek.",
    "Recognized people will show up here" : "Rozpoznaní lidé se zobrazí zde",
    "This folder does not exist" : "Tato složka neexistuje",
    "Loading folders …" : "Načítání složek…",
    "No photos in here" : "Tady nejsou žádné fotky",
    "Failed to fetch albums list." : "Nepodařilo se získat seznam alb.",
    "Shared albums" : "Sdílená alba",
    "Cover photo for shared album {albumName}." : "Foto na obálku sdíleného alba {albumName}.",
    "Back to tags overview" : "Zpět na přehled štítků",
    "No photos with this tag yet" : "Zatím žádné fotky s tímto štítkem",
    "No tags yet" : "Zatím žádné štítky",
    "Photos with tags will show up here" : "Fotky opatřené štítky se objeví zde",
    "Popular tags" : "Oblíbené štítky",
    "Add" : "Přidat",
    "Create a new album" : "Vytvořit nové album",
    "Add selection to an album" : "Přidat do alba výběr",
    "Add to album" : "Přidat do alba",
    "Delete selection" : "Smazat výběr",
    "No photos or videos in here" : "Nenacházejí se zde žádné fotky nebo videa",
    "Failed to fetch faces list." : "Nepodařilo se získat seznam obličejů.",
    "All your media" : "Veškerá vaše média",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Sdílená alba",
    "Shared album {title}" : "Sdílené album {title}",
    "Public album {title}" : "Veřejné album {title}",
    "Tagged photos" : "Oštítkované fotky",
    "Tagged photo {title}" : "Fotka {title} opatřena štítkem",
    "{title}'s face" : "Obličej {title}",
    "Failed to create {albumName}." : "Nepodařilo se vytvořit {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Nepodařilo přejmenovat {currentAlbumName} to {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Nepodařilo se přejmenovat {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nepodařilo se smazat {faceName}.",
    "Failed to delete {fileId}." : "Nepodařilo se smazat {fileId}.",
    "Failed to delete {fileName}." : "Nepodařilo se smazat {fileName}.",
    "Failed to set favorite state for {fileId}." : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileId}.",
    "Failed to set favorite state for {fileName}." : "Nepodařil se nastavit stav zařazení mezi oblíbené pro {fileName}.",
    "Your photos" : "Vaše fotky",
    "Your videos" : "Vaše videa",
    "Your folders" : "Vaše složky",
    "Settings" : "Nastavení"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-25.0.7.tgz: nextcloud/apps/photos/l10n/cs.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Veřejný odkaz",
    "Photos" : "Fotky",
    "Your memories under your control" : "Vaše vzpomínky pod vaší kontrolou",
    "All media" : "Veškerá média",
    "Videos" : "Videa",
    "Albums" : "Alba",
    "Collaborative albums" : "Alba pro spolupráci",
    "People" : "Lidé",
    "Folders" : "Složky",
    "Favorites" : "Oblíbené",
    "On this day" : "V tento den",
    "Shared with you" : "Sdíleno s vámi",
    "Tags" : "Štítky",
    "Places" : "Místa",
    "Map" : "Mapa",
    "Photos settings" : "Nastavení pro Fotky",
    "Mark selection as favorite" : "Označit vybrané jako oblíbené",
    "Add selection to favorites" : "Přidat vybrané do oblíbených",
    "Remove selection from favorites" : "Odebrat vybrané z oblíbených",
    "Name of the album" : "Název alba",
    "Location of the album" : "Umístění alba",
    "Go back to the previous view." : "Jít zpět na předchozí pohled.",
    "Back" : "Zpět",
    "Go to the add collaborators view." : "Jít na pohled přidání spolupracujících.",
    "Add collaborators" : "Přidat spolupracující",
    "Save." : "Uložit.",
    "Create the album." : "Vytvořit album.",
    "Save" : "Uložit",
    "Create album" : "Vytvořit album",
    "Back to the new album form." : "Zpět na formulář pro nové album.",
    "Add to Album" : "Přidat do alba",
    "Add selection to album {albumName}" : "Přidat výběr do alba {albumName}",
    "Create a new album." : "Vytvořit nové album.",
    "Create new album" : "Vytvořit nové album",
    "New album" : "Nové album",
    "_%n item_::_%n photos and videos_" : ["%n položka","%n fotky a videa","%n fotek a videí","%n fotky a videa"],
    "_Share with %n user_::_Share with %n users_" : ["Nasdílet %n uživateli","Nasdílet %n uživatelům","Nasdílet %n uživatelům","Nasdílet %n uživatelům"],
    "Add people or groups who can edit your album" : "Přidejte uživatele či skupiny, kteří mohou album upravovat",
    "Search for collaborators" : "Vyhledat spolupracující",
    "Search people or groups" : "Hledat uživatele nebo skupiny",
    "Add {collaboratorLabel} to the collaborators list" : "Přidat {collaboratorLabel} na seznam spolupracujících",
    "No collaborators available" : "Nejsou k dispozici žádní spolupracující",
    "Remove {collaboratorLabel} from the collaborators list" : "Odebrat {collaboratorLabel} ze seznamu spolupracujících",
    "Copy the public link" : "Zkopírovat veřejný odkaz",
    "Public link copied!" : "Veřejný odkaz zkopírován!",
    "Copy public link" : "Zkopírovat veřejný odkaz",
    "Delete the public link" : "Zkopírovat veřejný odkaz",
    "Share via public link" : "Nasdílet prostřednictvím veřejného odkazu",
    "Failed to fetch collaborators list." : "Nepodařilo se získat seznam spolupracujících.",
    "Failed to fetch album." : "Album se nepodařilo stáhnout.",
    "Failed to update album." : "Album se nepodařilo aktualizovat.",
    "This collection does not exist" : "Tato sbírka neexistuje",
    "An error occurred" : "Došlo k chybě",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "Select image {imageName}" : "Vybrat obrázek {imageName}",
    "The file is in the favorites" : "Soubor je v oblíbených",
    "Open the full size \"{name}\" image" : "Otevřít obrázek „{name}“ v plné velikosti",
    "There are no photos or videos yet!" : "Zatím zde nejsou žádné fotky či videa!",
    "Add to {destination}" : "Přidat do {destination}",
    "Open the \"{name}\" sub-directory" : "Otevřít podsložku „{name}“",
    "Back to {folder}" : "Zpět do {folder}",
    "Share this folder" : "Sdílet tuto složku",
    "_{years} year ago_::_{years} years ago_" : ["Před {years} rokem","Před {years} roky","Před {years} lety","Před {years} roky"],
    "Enable squared photos view" : "Zapnout čtvercové zobrazení fotek",
    "Default Photos upload and Albums location" : "Výchozí umístění nahrávání fotek a alb",
    "Select the default location for your media" : "Vyberte výchozí umístění pro vaše média",
    "Invalid location selected" : "Vybráno neplatné umístění",
    "View" : "Zobrazit",
    "Photos directory" : "Složka pro fotky",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "Manage collaborators for this album" : "Spravovat spolupracující pro toto album",
    "Open actions menu" : "Otevřít nabídku akcí",
    "Edit album details" : "Upravit podrobnosti o albu",
    "Download all files in album" : "Stáhnout veškeré soubory v albu",
    "Delete album" : "Smazat album",
    "Download selected files" : "Stáhnout si označené soubory",
    "Remove selection from album" : "Odebrat vybrané z alba",
    "This album does not have any photos or videos yet!" : "Toto album zatím neobsahuje žádné fotky či videa!",
    "Add photos to this album" : "Přidat fotky do tohoto alba",
    "Add photos to the album" : "Přidat fotky do alba",
    "Manage collaborators" : "Spravovat spolupracující",
    "Save collaborators for this album." : "Uložit spolupracující pro toto album.",
    "Cover photo for album {albumName}" : "Foto na obálku alba {albumName}",
    "There is no album yet!" : "Zatím zde nejsou žádná alba",
    "This person could not be found" : "Tuto osobu se nepodařilo nalézt",
    "Rename person" : "Přejmenovat osobu",
    "Merge with different person" : "Sloučit s jinou osobou",
    "Download selected photos" : "Stáhnout si označené fotky",
    "Favorite" : "Přidat do oblíbených",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Remove person" : "Odebrat osobu",
    "Name of this person" : "Pojmenovat tuto osobu",
    "Merge person" : "Sloučit osobu",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Přesunout fotku k jiné osobě","Přesunout fotky k jiné osobě","Přesunout fotky k jiné osobě","Přesunout fotky k jiné osobě"],
    "_Remove photo from person_::_Remove photos from person_" : ["Odebrat fotku z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby"],
    "This might take some time depending on the size of your photo library." : "Toto může zabrat nějakou dobu v závislosti na velikosti vaší knihovny fotek.",
    "Recognized people will show up here" : "Rozpoznaní lidé se zobrazí zde",
    "This folder does not exist" : "Tato složka neexistuje",
    "Loading folders …" : "Načítání složek…",
    "No photos in here" : "Tady nejsou žádné fotky",
    "This place does not have any photos or videos yet!" : "Toto umístění zatím nemá ještě žádné fotky nebo videa!",
    "Add photos to this place" : "Přidat tomuto umístění nějaké fotky",
    "Cover photo for place {placeName}" : "Foto na obálku pro umístění {placeName}",
    "There is no place yet!" : "Zatím zde není žádné umístění!",
    "Failed to fetch albums list." : "Nepodařilo se získat seznam alb.",
    "Shared albums" : "Sdílená alba",
    "Cover photo for shared album {albumName}." : "Foto na obálku sdíleného alba {albumName}.",
    "Back to tags overview" : "Zpět na přehled štítků",
    "No photos with this tag yet" : "Zatím žádné fotky s tímto štítkem",
    "No tags yet" : "Zatím žádné štítky",
    "Photos with tags will show up here" : "Fotky opatřené štítky se objeví zde",
    "Popular tags" : "Oblíbené štítky",
    "Add" : "Přidat",
    "Create a new album" : "Vytvořit nové album",
    "Add selection to an album" : "Přidat do alba výběr",
    "Add to album" : "Přidat do alba",
    "Delete selection" : "Smazat výběr",
    "No photos or videos in here" : "Nenacházejí se zde žádné fotky nebo videa",
    "Failed to fetch collection." : "Sbírku se nepodařilo stáhnout.",
    "Failed to fetch collections list." : "Nepodařilo se získat seznam sbírek.",
    "Failed to fetch faces list." : "Nepodařilo se získat seznam obličejů.",
    "All your media" : "Veškerá vaše média",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Sdílená alba",
    "Shared album {title}" : "Sdílené album {title}",
    "Public album {title}" : "Veřejné album {title}",
    "Tagged photos" : "Oštítkované fotky",
    "Tagged photo {title}" : "Fotka {title} opatřena štítkem",
    "{title}'s face" : "Obličej {title}",
    "Failed to create {albumName}." : "Nepodařilo se vytvořit {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Nepodařilo přejmenovat {currentAlbumName} to {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Nepodařilo se přejmenovat {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nepodařilo se smazat {faceName}.",
    "Failed to delete {fileId}." : "Nepodařilo se smazat {fileId}.",
    "Failed to delete {fileName}." : "Nepodařilo se smazat {fileName}.",
    "Failed to set favorite state for {fileId}." : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileId}.",
    "Failed to set favorite state for {fileName}." : "Nepodařil se nastavit stav zařazení mezi oblíbené pro {fileName}.",
    "Your photos" : "Vaše fotky",
    "Your videos" : "Vaše videa",
    "Your folders" : "Vaše složky",
    "Locations" : "Umístění",
    "Settings" : "Nastavení"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
